@@ -126,7 +126,7 @@ def _build_ptx_book(config, gen, manifest, course, click=click):
         root = tree.getroot()
         ElementInclude.include(root, base_url=main_file)  # include all xi:include parts
         if gen:
-            res = subprocess.call("pretext generate", shell=True)
+            res = subprocess.call("pretext generate -t runestone", shell=True)
             if res != 0:
                 click.echo("Failed to build")
             # build the book
@@ -291,14 +291,14 @@ def update_library(
         return False
 
     build_time = datetime.datetime.utcnow()
-    click.echo("BUILD time is {build_time}")
+    click.echo(f"BUILD time is {build_time}")
     if res.rowcount == 0:
         eng.execute(
             f"""insert into library
         (title, subtitle, description, shelf_section, basecourse,
-            build_system, main_page, last_build )
+            build_system, main_page, last_build, for_classes, is_visible )
         values('{title}', '{subtitle}', '{description}', '{shelf}', '{course}',
-        '{build_system}', '{main_page}', '{build_time}') """
+        '{build_system}', '{main_page}', '{build_time}', 'F', 'T') """
         )
     else:
         # If any values are missing or null do not override them here.
